"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signTypedData = signTypedData;
const viem_1 = require("viem");
const actions_1 = require("viem/actions");
const constants_js_1 = require("../constants.js");
const eip712_js_1 = require("../eip712.js");
const getAgwTypedSignature_js_1 = require("../getAgwTypedSignature.js");
const sendPrivyTransaction_js_1 = require("./sendPrivyTransaction.js");
async function signTypedData(client, signerClient, parameters, isPrivyCrossApp = false) {
    if (isPrivyCrossApp)
        return await (0, sendPrivyTransaction_js_1.sendPrivySignTypedData)(client, parameters);
    if (parameters.message &&
        parameters.domain?.name === 'zkSync' &&
        (0, eip712_js_1.isEIP712Transaction)(parameters.message)) {
        const rawSignature = await (0, actions_1.signTypedData)(signerClient, parameters);
        const signature = (0, viem_1.encodeAbiParameters)((0, viem_1.parseAbiParameters)(['bytes', 'address', 'bytes[]']), [rawSignature, constants_js_1.VALIDATOR_ADDRESS, []]);
        return signature;
    }
    return await (0, getAgwTypedSignature_js_1.getAgwTypedSignature)({
        client,
        signer: signerClient,
        messageHash: (0, viem_1.hashTypedData)(parameters),
    });
}
//# sourceMappingURL=signTypedData.js.map