import { encodeAbiParameters, encodeFunctionData, keccak256, parseAbiParameters, serializeErc6492Signature, toBytes, zeroAddress, } from 'viem';
import { signTypedData } from 'viem/actions';
import AccountFactoryAbi from './abis/AccountFactory.js';
import { SMART_ACCOUNT_FACTORY_ADDRESS, VALIDATOR_ADDRESS, } from './constants.js';
import { getInitializerCalldata } from './utils.js';
export async function getAgwTypedSignature(args) {
    const { client, signer, messageHash } = args;
    const chainId = client.chain.id;
    const account = client.account;
    const rawSignature = await signTypedData(signer, {
        domain: {
            name: 'AbstractGlobalWallet',
            version: '1.0.0',
            chainId: BigInt(chainId),
            verifyingContract: account.address,
        },
        types: {
            EIP712Domain: [
                { name: 'name', type: 'string' },
                { name: 'version', type: 'string' },
                { name: 'chainId', type: 'uint256' },
                { name: 'verifyingContract', type: 'address' },
            ],
            ClaveMessage: [{ name: 'signedHash', type: 'bytes32' }],
        },
        message: {
            signedHash: messageHash,
        },
        primaryType: 'ClaveMessage',
    });
    const signature = encodeAbiParameters(parseAbiParameters(['bytes', 'address']), [rawSignature, VALIDATOR_ADDRESS]);
    const addressBytes = toBytes(signer.account.address);
    const salt = keccak256(addressBytes);
    return serializeErc6492Signature({
        address: SMART_ACCOUNT_FACTORY_ADDRESS,
        data: encodeFunctionData({
            abi: AccountFactoryAbi,
            functionName: 'deployAccount',
            args: [
                salt,
                getInitializerCalldata(signer.account.address, VALIDATOR_ADDRESS, {
                    target: zeroAddress,
                    allowFailure: false,
                    callData: '0x',
                    value: 0n,
                }),
            ],
        }),
        signature,
    });
}
//# sourceMappingURL=getAgwTypedSignature.js.map