import { type Account, type Address, type Chain, type Client, type PrepareTransactionRequestReturnType, type PublicClient, type SendTransactionRequest, type SendTransactionReturnType, type SignMessageParameters, type SignMessageReturnType, type SignTypedDataParameters, type SignTypedDataReturnType, type Transport, type WalletClient } from 'viem';
import { type ChainEIP712, type Eip712WalletActions } from 'viem/zksync';
import { type PrepareTransactionRequestParameters, type PrepareTransactionRequestRequest } from './actions/prepareTransaction.js';
import type { SendTransactionBatchParameters } from './types/sendTransactionBatch.js';
export type AbstractWalletActions<chain extends ChainEIP712 | undefined = ChainEIP712 | undefined, account extends Account | undefined = Account | undefined> = Eip712WalletActions<chain, account> & {
    signMessage: (args: Omit<SignMessageParameters, 'account'>) => Promise<SignMessageReturnType>;
    signTypedData: (args: Omit<SignTypedDataParameters, 'account' | 'privateKey'>) => Promise<SignTypedDataReturnType>;
    sendTransactionBatch: <const request extends SendTransactionRequest<ChainEIP712>>(args: SendTransactionBatchParameters<request>) => Promise<SendTransactionReturnType>;
    prepareAbstractTransactionRequest: <chain extends ChainEIP712 | undefined = ChainEIP712 | undefined, account extends Account | undefined = Account | undefined, accountOverride extends Account | Address | undefined = undefined, chainOverride extends ChainEIP712 | undefined = ChainEIP712 | undefined, const request extends PrepareTransactionRequestRequest<chain, chainOverride> = PrepareTransactionRequestRequest<chain, chainOverride>>(args: PrepareTransactionRequestParameters<chain, account, chainOverride, accountOverride, request>) => Promise<PrepareTransactionRequestReturnType>;
};
export declare function globalWalletActions<chain extends ChainEIP712 | undefined = ChainEIP712 | undefined, account extends Account | undefined = Account | undefined>(signerClient: WalletClient<Transport, ChainEIP712, Account>, publicClient: PublicClient<Transport, ChainEIP712>, isPrivyCrossApp?: boolean): (client: Client<Transport, ChainEIP712, Account>) => AbstractWalletActions<Chain, Account>;
//# sourceMappingURL=walletActions.d.ts.map